CONTENTS OF THIS FILE
---------------------
 * Introduction
 * Requirements
 * Developing a plugin
 * Installation
 * Configuration
 * Developers
 * Maintainers

INTRODUCTION
------------
The overview builder is a developer module that adds a new plugin type
"overview_builder" that allows to add an overview (views or custom) to your
entities. The benefit of this module is that your overview pages are also
e.g. nodes, so the path, metatags, header and footer text, ... can be
configured by a content manager.

This module depends on the "pluginreference" module to reference to your
overview plugin. When the "paragraphs" module is enabled, this module
will create a default "overview" paragraph with an overview field from where
you can reference to your custom plugins. Your overviews can now be used
in a paragraph setup.

When you do not prefer paragraphs, you can create your own "overview" field by
adding a field that references to the OverviewBuilder plugin.

REQUIREMENTS
------------
- pluginreference
- paragraphs (optional)

INSTALLATION
------------
Install the "Overview Builder" module as
you would normally install a contributed Drupal module.

Visit https://www.drupal.org/node/1897420 for further
information.

When the "paragraphs" module is enabled, this module will create a default
"overview" paragraph with an overview field from where you can reference
to your custom plugins.

DEVELOPING A PLUGIN
-------------------
There is an overview_builder_example module, located in
modules/overview_builder_example

To create a plugin. Create a file in
``src/Plugin/OverviewBuilder``

This module provides 2 base plugin classes:

### Views overview

When you want to reference to a views overview, the following annotation is
required:
```
@OverviewBuilder(
  id = "views_overview",
  label = @Translation("Views Overview"),
  view_id = "news",
  display_id = "page_1",
)
```

And that's it. After clearing the cache, and referencing to your plugin, the
view overview will be displayed on your entity.

### Custom overview

When the views module is not sufficient for your needs, or you need more
flexibility, you can create a custom overview. the following annotation is
required:
```
@OverviewBuilder(
  id = "advanced_node_overview",
  label = @Translation("Advanced Node overview"),
  entity_type = "node",
  view_mode = "teaser",
)
```

The entity_type property defines the entity type that is used in the overview.
This entity_type is used for setting cache_tags for your overview.
The view_mode property defines the view_mode of your entities that is used
in the overview.

The `getListEntities()` method in your custom plugin returns the entities
that are shown in the overview.

CONFIGURATION
-------------
When the "paragraphs" module is enabled, this module will create a default
"overview" paragraph with an overview field from where you can reference
to your custom plugins.

When creating a node you can now add an "overview" paragraph. In this
paragraph you can reference your custom overview.

When your project does not contain a paragraph setup, you can add your own
"overview" field.

On an entity of your choice e.g. Node, add a new field of the type
"Plugin reference" and reference to the
"Drupal\overview_builder\OverviewBuilderManager" plugin. On the manage display
page, choose the format "Plugin Reference overview builder" to show your
overview.

DEVELOPERS
----------
* Jeroen Tubex - https://www.drupal.org/u/jeroent
* Arno Van de Weyer - https://www.drupal.org/u/waldoswndrwrld

MAINTAINERS
-----------
Current maintainers:
* Jeroen Tubex - https://www.drupal.org/u/jeroent
* Arno Van de Weyer - https://www.drupal.org/u/waldoswndrwrld
